<?php
/**
 * Copyright (C) 2021 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Alexander Purr <purr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */
use fid\Hydrator\OrderMissingRecordHydrator;
use Zend\Filter\StringTrim;
use Zend\Form\Element\Text;
use Zend\Validator\NotEmpty;
use Zend\Validator\StringLength;

$main_config = require 'fid-acquisition-digitization-form.php';
unset($main_config['name'], $main_config['hydrator']);

$additional_config = [
    'name'         => 'fid-acquisition-missing-record-form',
    'hydrator'     => OrderMissingRecordHydrator::class,
    'elements'     => [
        'title'              => [
            'spec' => [
                'name'       => 'title',
                'type'       => Text::class,
                'options'    => [
                    'label' => 'acquisition_label_title',
                ],
                'attributes' => [
                    'required' => 'required',
                ],
            ],
        ],
        'responsible'              => [
            'spec' => [
                'name'       => 'responsible',
                'type'       => Text::class,
                'options'    => [
                    'label' => 'acquisition_label_responsible',
                ],
            ],
        ],
        'year'              => [
            'spec' => [
                'name'       => 'year',
                'type'       => Text::class,
                'options'    => [
                    'label' => 'acquisition_label_year',
                ],
            ],
        ],
        'language'              => [
            'spec' => [
                'name'       => 'language',
                'type'       => Text::class,
                'options'    => [
                    'label' => 'acquisition_label_language',
                ],
            ],
        ],
        'input_filter' => [
            'title'               => [
                'name'       => 'title',
                'required'   => true,
                'filters'    => [
                    StringTrim::class => [
                        'name' => StringTrim::class,
                    ],
                ],
                'validators' => [
                    NotEmpty::class => [
                        'name' => NotEmpty::class,
                    ],
                    StringLength::class => [
                        'name'    => StringLength::class,
                        'options' => [
                            'max' => 1000
                        ],
                    ],
                ],
            ],
            'responsible'       => [
                'name'       => 'responsible',
                'required'   => false,
                'filters'    => [
                    StringTrim::class => [
                        'name' => StringTrim::class,
                    ],
                ],
                'validators' => [
                    StringLength::class => [
                        'name'    => StringLength::class,
                        'options' => [
                            'max' => 1000
                        ],
                    ],
                ],
            ],
            'year'               => [
                'name'       => 'year',
                'required'   => false,
                'filters'    => [
                    StringTrim::class => [
                        'name' => StringTrim::class,
                    ],
                ],
                'validators' => [
                    StringLength::class => [
                        'name'    => StringLength::class,
                        'options' => [
                            'max' => 256
                        ],
                    ],
                ],
            ],
            'language'               => [
                'name'       => 'language',
                'required'   => false,
                'filters'    => [
                    StringTrim::class => [
                        'name' => StringTrim::class,
                    ],
                ],
                'validators' => [
                    StringLength::class => [
                        'name'    => StringLength::class,
                        'options' => [
                            'max' => 256
                        ],
                    ],
                ],
            ],
        ],
    ]
];

return array_merge_recursive($main_config, $additional_config);
