<?php
/**
 * Order update hydrator
 *
 * Copyright (C) 2021 Leipzig University Library
 *
 * PHP Version 7
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @category VuFind
 * @package  Hydrator
 * @author   Alexander Purr <purr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\Hydrator;

use fid\Service\DataTransferObject\Order;
use Zend\Hydrator\AbstractHydrator;

/**
 * Order update hydrator for getting order data
 * or update aquistions data correctly before sending to fidis
 *
 * @category VuFind
 * @package  Hydrator
 * @author   Alexander Purr <purr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
class OrderUpdateHydrator extends AbstractHydrator
{
    public const DATE_FORMAT = 'Y-m-d';

    /**
     * Extract and return due date and status
     *
     * @param Order $object Order object
     *
     * @return array
     */
    public function extract($object)
    {
        $retval['due_date'] = $object->getDueDate()
            ? $object->getDueDate()->format(self::DATE_FORMAT) : '';
        $retval['status'] = $object->getStatus() ?? 'open';
        return $retval;
    }

    /**
     * Save due date and status to order
     *
     * @param array $data   Data to save to order object
     * @param Order $object Order object
     *
     * @return Order
     */
    public function hydrate(array $data, $object)
    {
        $data['status'] ? $object->setStatus($data['status']) : null;
        !empty($data['due_date'])
            ? $object->setDueDate(
                \DateTime::createFromFormat(
                    self::DATE_FORMAT,
                    $data['due_date']
                )
            )
            : null;
        return $object;
    }
}
