<?php
/**
 * User Hydrator Delegator Factory
 *
 * Copyright (C) 2019 Leipzig University Library
 *
 * PHP Version 7
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @category VuFind
 * @package  Hydrator
 * @author   Gregor Gawol <gawol@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\Hydrator;

use fid\Hydrator\Strategy\UserDataStrategy;
use fid\Service\DataTransferObject\Address;
use Interop\Container\ContainerInterface;
use Zend\Hydrator\AbstractHydrator;
use Zend\Hydrator\ClassMethods;
use Zend\Hydrator\Strategy\CollectionStrategy;
use Zend\ServiceManager\Factory\DelegatorFactoryInterface;

/**
 * User Hydrator Delegator Factory
 *
 * @category VuFind
 * @package  Hydrator
 * @author   Gregor Gawol <gawol@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
class UserHydratorDelegatorFactory implements DelegatorFactoryInterface
{
    /**
     * Init user hydrator object and apply naming strategy
     *
     * @param ContainerInterface $container Service Container
     * @param $name      Class name
     * @param callable           $callback  Callback funcktion
     * @param array|null         $options   Options
     *
     * @return AbstractHydrator
     */
    public function __invoke(
        ContainerInterface $container,
        $name,
        callable $callback,
        array $options = null
    ) {
        /* @var AbstractHydrator $hydrator */
        $hydrator = call_user_func($callback);
        $namingStrategy = $hydrator->getNamingStrategy();
        $hydrator->addStrategy('data', new UserDataStrategy($namingStrategy));
        $strategy = new CollectionStrategy(new ClassMethods(), Address::class);
        $hydrator->addStrategy('addresses', $strategy);

        return $hydrator;
    }
}
