<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * PHP Version 7
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Serializer for Order Requests to FIDIS API
 * https://git.sc.uni-leipzig.de/ubl/finc/fid/fidis/-/blob/master/bundle/Entity/Order.php
 *
 * @category VuFind
 * @package  Serializer
 * @author   Gregor Gawol <gawol@ub.uni-leipzig.de>
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\Serializer;

use fid\Service\DataTransferObject\User;
use Symfony\Component\Serializer\Normalizer\ContextAwareNormalizerInterface;
use Symfony\Component\Serializer\Normalizer\NormalizerAwareInterface;
use Symfony\Component\Serializer\Normalizer\NormalizerAwareTrait;

/**
 * Class OrderCreationRequestUserNormalizer
 *
 * Serializer for Order Requests to FIDIS API
 * https://git.sc.uni-leipzig.de/ubl/finc/fid/fidis/-/blob/master/bundle/Entity/Order.php
 *
 * @category VuFind
 * @package  Serializer
 * @author   Gregor Gawol <gawol@ub.uni-leipzig.de>
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
class OrderCreationRequestUserNormalizer implements
    ContextAwareNormalizerInterface, NormalizerAwareInterface
{
    use NormalizerAwareTrait;

    /**
     * {@inheritdoc}
     *
     * @param mixed $data    Order data
     * @param null  $format  Format the normalization result will be encoded as
     * @param array $context Context options for the normalizer
     *
     * @return bool true if Serializer supports normalization otherwise false
     */
    public function supportsNormalization(
        $data,
        $format = null,
        array $context = []
    ) {
        return $data instanceof User
            && in_array('order:creation:request', $context['groups'] ?? []);
    }

    /**
     * {@inheritdoc}
     *
     * @param mixed|User $object  Object to normalize
     * @param null       $format  Format the normalization result will be encoded as
     * @param array      $context Context options for the normalizer
     *
     * @return array|bool|float|int|string
     */
    public function normalize($object, $format = null, array $context = [])
    {
        return $object->getId();
    }
}
