<?php
/**
 * FID dto for libraries
 *
 * Copyright (C) 2019 Leipzig University Library
 *
 * PHP version 7
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @category VuFind
 * @package  Service
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\Service\DataTransferObject;

/**
 * FID library dto class
 *
 * @category VuFind
 * @package  Service
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
class Library
{
    /* @var string */
    protected $id;

    /* @var string */
    protected $ezb = '';

    /* @var string */
    protected $dbis = '';

    /* @var string */
    protected $network = '';

    /* @var string */
    protected $boss = '';

    /* @var string */
    protected $isil = '';

    /* @var string */
    protected $label = '';

    /**
     * Get identifier
     *
     * @return string
     */
    public function getId(): string
    {
        return $this->id;
    }

    /**
     * Set identifier
     *
     * @param string $id identifier
     *
     * @return void
     */
    public function setId(string $id): void
    {
        $this->id = $id;
    }

    /**
     * Get Electronic Journal Database
     *
     * @return string
     */
    public function getEzb(): string
    {
        return $this->ezb;
    }

    /**
     * Get Electronic Journal Database
     *
     * @param string $ezb ezb
     *
     * @return void
     */
    public function setEzb(string $ezb): void
    {
        $this->ezb = $ezb;
    }

    /**
     * Get Database Information System
     *
     * @return string
     */
    public function getDbis(): string
    {
        return $this->dbis;
    }

    /**
     * Set Database Information System
     *
     * @param string $dbis dbis
     *
     * @return void
     */
    public function setDbis(string $dbis): void
    {
        $this->dbis = $dbis;
    }

    /**
     * Get network
     *
     * @return string
     */
    public function getNetwork(): string
    {
        return $this->network;
    }

    /**
     * Set Network
     *
     * @param string $network network
     *
     * @return void
     */
    public function setNetwork(string $network): void
    {
        $this->network = $network;
    }

    /**
     * Get BSZ One Stop Search
     *
     * @return string
     */
    public function getBoss(): string
    {
        return $this->boss;
    }

    /**
     * Set BSZ One Stop Search
     *
     * @param string $boss BOSS
     *
     * @return void
     */
    public function setBoss(string $boss): void
    {
        $this->boss = $boss;
    }

    /**
     * Get international standard identifier
     *
     * @return string
     */
    public function getIsil(): string
    {
        return $this->isil;
    }

    /**
     * Set international standard identifier
     *
     * @param string $isil ISIL
     *
     * @return void
     */
    public function setIsil(string $isil): void
    {
        $this->isil = $isil;
    }

    /**
     * Get label
     *
     * @return string
     */
    public function getLabel(): string
    {
        return $this->label;
    }

    /**
     * Set label
     *
     * @param string $label label
     *
     * @return void
     */
    public function setLabel(string $label): void
    {
        $this->label = $label;
    }
}
