<?php
/**
 * Dto for fid session
 *
 * Copyright (C) 2019 Leipzig University Library
 *
 * PHP version 7
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @category VuFind
 * @package  Service
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\Service\DataTransferObject;

/**
 * FID logon dto class
 *
 * @category VuFind
 * @package  Service
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
class Logon
{
    /* @var string|null */
    protected $username;

    /* @var string|null */
    protected $password;

    /* @var int|null */
    protected $stalesAt;

    /* @var int|null */
    protected $expiresAt;

    /* @var string|null */
    protected $token;

    /* @var string|null */
    protected $ownerId;

    /**
     * Get name of user
     *
     * @return string|null
     */
    public function getUsername(): ?string
    {
        return $this->username;
    }

    /**
     * Set name of user
     *
     * @param string|null $username username
     *
     * @return void
     */
    public function setUsername(?string $username): void
    {
        $this->username = $username;
    }

    /**
     * Get user password
     *
     * @return string|null
     */
    public function getPassword(): ?string
    {
        return $this->password;
    }

    /**
     * Set user password
     *
     * @param string|null $password password
     *
     * @return void
     */
    public function setPassword(?string $password): void
    {
        $this->password = $password;
    }

    /**
     * Get auth token
     *
     * @return string|null token
     */
    public function getToken(): ?string
    {
        return $this->token;
    }

    /**
     * Get time in seconds when logon will stale
     *
     * @return int|null
     */
    public function getStalesAt(): ?int
    {
        return $this->stalesAt;
    }

    /**
     * Set time in seconds when logon will stale
     *
     * @param int|null $stalesAt stales at
     *
     * @return void
     */
    public function setStalesAt(?int $stalesAt): void
    {
        $this->stalesAt = $stalesAt;
    }

    /**
     * Get time in seconds when logon will expire
     *
     * @return int|null
     */
    public function getExpiresAt(): ?int
    {
        return $this->expiresAt;
    }

    /**
     * Set time in seconds when logon will expire
     *
     * @param int|null $expiresAt expires at
     *
     * @return void
     */
    public function setExpiresAt(?int $expiresAt): void
    {
        $this->expiresAt = $expiresAt;
    }

    /**
     * Set token
     *
     * @param string|null $token token
     *
     * @return void
     */
    public function setToken(?string $token): void
    {
        $this->token = $token;
    }

    /**
     * Get owner identifier
     *
     * @return string|null
     */
    public function getOwnerId(): ?string
    {
        return $this->ownerId;
    }

    /**
     * Set owner identifier
     *
     * @param string|null $ownerId owner id
     *
     * @return void
     */
    public function setOwnerId(?string $ownerId): void
    {
        $this->ownerId = $ownerId;
    }
}
