<?php
/**
 * Subito partial copy page order validator
 *
 * Copyright (C) 2020 Leipzig University Library
 *
 * PHP Version 7
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @category VuFind
 * @package  Validator
 * @author   Alexander Purr <purr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\Validator;

use Zend\Validator\AbstractValidator;

/**
 * Subito partial copy page order validator
 *
 * @category VuFind
 * @package  Validator
 * @author   Alexander Purr <purr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
class SubitoPartialCopyPageOrder extends AbstractValidator
{
    use SubitoPartialCopyPageRangeValidatorTrait;

    public const PAGES_ORDER = 'subitoPartialCopyPageOrder';

    protected $messageTemplates = [
        self::PAGES_ORDER => "acquisition_error_page_order",
    ];

    /**
     * Validate if given page range is ordered correctly
     *
     * @param string $value From to page range
     *
     * @return bool
     */
    public function isValid($value): bool
    {
        $this->_extractPages($value);

        if ($this->_pageStart > $this->_pageEnd) {
            $this->error(self::PAGES_ORDER);
            return false;
        } else {
            return true;
        }
    }
}
