<?php
/**
 * Factory for record driver data formatting view helper
 *
 * PHP version 7
 *
 * Copyright (C) Villanova University 2016.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Alexander Purr <purr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\View\Helper\Root;

use finc\View\Helper\Root\RecordDataFormatterFactory as Base;
use VuFind\View\Helper\Root\RecordDataFormatter;
use VuFind\View\Helper\Root\RecordDataFormatter\SpecBuilder;

/**
 * Record Data Formatter Factory for Record view
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Alexander Purr <purr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
class RecordDataFormatterFactory extends Base
{
    /**
     * Create the helper.
     *
     * @return RecordDataFormatter
     */
    public function __invoke()
    {
        $helper = parent::__invoke();

        $helper->setDefaults(
            'fid-acquisition-general',
            [$this, 'getFidAcquisitionSpecs']
        );
        $helper->setDefaults(
            'fid-acquisition-subito-partial-copy',
            [$this, 'getFidAcquisitionSubitoPartialCopySpecs']
        );

        return $helper;
    }

    /**
     * Get general specifications for displaying data in fid pda form.
     *
     * @return array
     */
    public function getFidAcquisitionSpecBuilder()
    {
        $spec = new SpecBuilder();
        $spec->setLine('Title', 'getTitle');
        $spec->setTemplateLine(
            'Authors/Corporations',
            'getDeduplicatedAuthors',
            'data-authors.phtml',
            [
                'useCache' => true,
                'context' => [
                    'requiredDataFields' => [
                        ['name' => 'role', 'prefix' => 'CreatorRoles::']
                    ]
                ]
            ]
        );
        $spec->setTemplateLine(
            'Published',
            'getPublicationDetails',
            'data-publicationDetails.phtml'
        );
        $spec->setTemplateLine(
            'Price',
            'getPrice',
            'data-price.phtml'
        );
        $spec->setLine('Language', 'getLanguages');
        return $spec;
    }

    /**
     * Get specifications for displaying data in fid pda form.
     *
     * @return array
     */
    public function getFidAcquisitionSpecs()
    {
        $spec = $this->getFidAcquisitionSpecBuilder();
        return $spec->getArray();
    }

    /**
     * Get specifications for displaying data in fid subito partial copy form.
     *
     * @return array
     */
    public function getFidAcquisitionSubitoPartialCopySpecs()
    {
        $spec = $this->getFidAcquisitionSpecBuilder();
        $spec->setLine('fid::number_of_pages', 'getNumberOfPages');
        return $spec->getArray();
    }
}
