<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * PHP Version 7
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @category VuFind
 * @package  Db
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\VuFind\Db\Row;

use fid\Service\Client;
use Psr\Container\ContainerInterface;

/**
 * Class UserDelegatorFactory
 * Adds Client to user object on creation
 *
 * @category VuFind
 * @package  Db
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
class UserDelegatorFactory
{
    /**
     * Adds Client to user object on creation
     *
     * @param ContainerInterface $container service container
     * @param string             $name      name of class to instantiate
     * @param callable           $callback  constructor callback
     *
     * @return User
     */
    public function __invoke(
        ContainerInterface $container,
        $name,
        callable $callback
    ) {
        /* @var User $user */
        $user = call_user_func($callback);
        $user->setClient($container->get(Client::class));

        return $user;
    }
}
