<?php
/**
 * Copyright (C) Leipzig University Library 2019.
 *
 * PHP Version 7
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Resolver
 * @author   Gregor Gawol <gawol@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\VuFind\Resolver\Driver;

use fid\Service\Client;
use Interop\Container\ContainerInterface;
use Zend\ServiceManager\Factory\DelegatorFactoryInterface;

/**
 * Class EzbDelegatorFactory
 *
 * @category VuFind
 * @package  Resolver
 * @author   Gregor Gawol <gawol@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 * @link     https://vufind.org/wiki/development Wiki
 */
class EzbDelegatorFactory implements DelegatorFactoryInterface
{
    /**
     * Create an Ezb object and set
     * config, fid client, ILS connection, and base URL
     *
     * @param ContainerInterface $container Service container
     * @param string             $name      class name for object to create
     * @param callable           $callback  instantiation callback
     * @param array|null         $options   options
     *
     * @return Ezb|object
     */
    public function __invoke(
        ContainerInterface $container,
        $name,
        callable $callback,
        array $options = null
    ) {
        $ezbConfig = $container->get('VuFind\Config')->get('Resolver');
        $fidClient = $container->get(Client::class);
        $ils = $container->get('VuFind\ILS\Connection');
        /* @var Ezb $ezb */
        $ezb = call_user_func($callback);
        $ezb->setConfig($ezbConfig->Ezb);
        $ezb->setFidClient($fidClient);
        $ezb->setIls($ils);
        $ezb->setBaseUrl($ezbConfig->Ezb->url);
        return $ezb;
    }
}
