<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */

namespace fid_adlr\Controller;

/**
 * Redirects the user to the appropriate default VuFind action.
 * Copied and modified from de_15/src/de_15/Controller/SearchController.php
 *
 * @category VuFind
 * @package  Controller
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 */
class SearchController extends \VuFindResultsGrouping\Controller\SearchController
{
    /**
     * Handle search history display && purge
     *
     * @return mixed
     */
    public function historyAction()
    {
        // Force login if necessary
        $user = $this->getUser();
        if ($this->params()->fromQuery('require_login', 'no') !== 'no' && !$user) {
            return $this->forceLogin();
        }

        // Retrieve search history
        $search = $this->getTable('Search');
        $searchHistory = $search->getSearches(
            $this->serviceLocator->get('VuFind\SessionManager')->getId(),
            is_object($user) ? $user->id : null
        );

        // Build arrays of history entries
        $saved = $unsaved = [];

        // Loop through the history
        foreach ($searchHistory as $current) {
            $minSO = $current->getSearchObject();

            // Saved searches
            if ($current->saved == 1) {
                $saved[] = $minSO->deminify($this->getResultsManager());
            } else {
                // All the others...

                // If this was a purge request we don't need this
                if ($this->params()->fromQuery('purge') == 'true') {
                    $current->delete();

                    // We don't want to remember the last search after a purge:
                    $this->getSearchMemory()->forgetSearch();
                } else {
                    // Otherwise add to the list
                    $unsaved[] = $minSO->deminify($this->getResultsManager());
                }
            }
        }

        $isLightbox = 'lightbox' === $this->params()->fromPost('layout', $this->params()->fromQuery('layout', false));

        return $this->createViewModel(
            [
                'saved' => $saved,
                'unsaved' => $unsaved,
                // hide the menu if we are rendering this view for the lightbox (modal)
                'showMenu' => !$isLightbox
            ]
        );
    }
}