<?php
/**
 * LuceneSyntaxHelper Override
 *
 * A Delegator Factory that registers several listeners at events triggered by the
 * VuFind\Search service.
 *
 * PHP version 7
 *
 * Copyright (C) Leipzig University Library 2021.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Finc/Service
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Page
 */
namespace finc\Service;

/**
 * LuceneSyntaxHelper Override
 *
 * @category VuFind
 * @package  Finc/Service
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Page
 */
class LuceneSyntaxHelperOverride extends \VuFindSearch\Backend\Solr\LuceneSyntaxHelper
{
    public function __construct(\VuFindSearch\Backend\Solr\LuceneSyntaxHelper $parentHelper)
    {
        parent::__construct(
            $parentHelper->caseSensitiveBooleans,
            $parentHelper->caseSensitiveRanges
        );
    }

    /**
     * {@inheritDoc}
     * overridden to avoid query rebuilding
     *
     * @param string $searchString
     * @return false
     */
    public function containsAdvancedLuceneSyntax($searchString)
    {
        return false;
    }
}
